import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { LexModelsV2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../LexModelsV2Client";
import { UpdateBotLocaleRequest, UpdateBotLocaleResponse } from "../models/models_1";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link UpdateBotLocaleCommand}.
 */
export interface UpdateBotLocaleCommandInput extends UpdateBotLocaleRequest {
}
/**
 * @public
 *
 * The output of {@link UpdateBotLocaleCommand}.
 */
export interface UpdateBotLocaleCommandOutput extends UpdateBotLocaleResponse, __MetadataBearer {
}
declare const UpdateBotLocaleCommand_base: {
    new (input: UpdateBotLocaleCommandInput): import("@smithy/smithy-client").CommandImpl<UpdateBotLocaleCommandInput, UpdateBotLocaleCommandOutput, LexModelsV2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: UpdateBotLocaleCommandInput): import("@smithy/smithy-client").CommandImpl<UpdateBotLocaleCommandInput, UpdateBotLocaleCommandOutput, LexModelsV2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Updates the settings that a bot has for a specific locale.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { LexModelsV2Client, UpdateBotLocaleCommand } from "@aws-sdk/client-lex-models-v2"; // ES Modules import
 * // const { LexModelsV2Client, UpdateBotLocaleCommand } = require("@aws-sdk/client-lex-models-v2"); // CommonJS import
 * const client = new LexModelsV2Client(config);
 * const input = { // UpdateBotLocaleRequest
 *   botId: "STRING_VALUE", // required
 *   botVersion: "STRING_VALUE", // required
 *   localeId: "STRING_VALUE", // required
 *   description: "STRING_VALUE",
 *   nluIntentConfidenceThreshold: Number("double"), // required
 *   voiceSettings: { // VoiceSettings
 *     voiceId: "STRING_VALUE", // required
 *     engine: "standard" || "neural",
 *   },
 *   generativeAISettings: { // GenerativeAISettings
 *     runtimeSettings: { // RuntimeSettings
 *       slotResolutionImprovement: { // SlotResolutionImprovementSpecification
 *         enabled: true || false, // required
 *         bedrockModelSpecification: { // BedrockModelSpecification
 *           modelArn: "STRING_VALUE", // required
 *           guardrail: { // BedrockGuardrailConfiguration
 *             identifier: "STRING_VALUE", // required
 *             version: "STRING_VALUE", // required
 *           },
 *           traceStatus: "ENABLED" || "DISABLED",
 *           customPrompt: "STRING_VALUE",
 *         },
 *       },
 *     },
 *     buildtimeSettings: { // BuildtimeSettings
 *       descriptiveBotBuilder: { // DescriptiveBotBuilderSpecification
 *         enabled: true || false, // required
 *         bedrockModelSpecification: {
 *           modelArn: "STRING_VALUE", // required
 *           guardrail: {
 *             identifier: "STRING_VALUE", // required
 *             version: "STRING_VALUE", // required
 *           },
 *           traceStatus: "ENABLED" || "DISABLED",
 *           customPrompt: "STRING_VALUE",
 *         },
 *       },
 *       sampleUtteranceGeneration: { // SampleUtteranceGenerationSpecification
 *         enabled: true || false, // required
 *         bedrockModelSpecification: {
 *           modelArn: "STRING_VALUE", // required
 *           guardrail: {
 *             identifier: "STRING_VALUE", // required
 *             version: "STRING_VALUE", // required
 *           },
 *           traceStatus: "ENABLED" || "DISABLED",
 *           customPrompt: "STRING_VALUE",
 *         },
 *       },
 *     },
 *   },
 * };
 * const command = new UpdateBotLocaleCommand(input);
 * const response = await client.send(command);
 * // { // UpdateBotLocaleResponse
 * //   botId: "STRING_VALUE",
 * //   botVersion: "STRING_VALUE",
 * //   localeId: "STRING_VALUE",
 * //   localeName: "STRING_VALUE",
 * //   description: "STRING_VALUE",
 * //   nluIntentConfidenceThreshold: Number("double"),
 * //   voiceSettings: { // VoiceSettings
 * //     voiceId: "STRING_VALUE", // required
 * //     engine: "standard" || "neural",
 * //   },
 * //   botLocaleStatus: "Creating" || "Building" || "Built" || "ReadyExpressTesting" || "Failed" || "Deleting" || "NotBuilt" || "Importing" || "Processing",
 * //   failureReasons: [ // FailureReasons
 * //     "STRING_VALUE",
 * //   ],
 * //   creationDateTime: new Date("TIMESTAMP"),
 * //   lastUpdatedDateTime: new Date("TIMESTAMP"),
 * //   recommendedActions: [ // RecommendedActions
 * //     "STRING_VALUE",
 * //   ],
 * //   generativeAISettings: { // GenerativeAISettings
 * //     runtimeSettings: { // RuntimeSettings
 * //       slotResolutionImprovement: { // SlotResolutionImprovementSpecification
 * //         enabled: true || false, // required
 * //         bedrockModelSpecification: { // BedrockModelSpecification
 * //           modelArn: "STRING_VALUE", // required
 * //           guardrail: { // BedrockGuardrailConfiguration
 * //             identifier: "STRING_VALUE", // required
 * //             version: "STRING_VALUE", // required
 * //           },
 * //           traceStatus: "ENABLED" || "DISABLED",
 * //           customPrompt: "STRING_VALUE",
 * //         },
 * //       },
 * //     },
 * //     buildtimeSettings: { // BuildtimeSettings
 * //       descriptiveBotBuilder: { // DescriptiveBotBuilderSpecification
 * //         enabled: true || false, // required
 * //         bedrockModelSpecification: {
 * //           modelArn: "STRING_VALUE", // required
 * //           guardrail: {
 * //             identifier: "STRING_VALUE", // required
 * //             version: "STRING_VALUE", // required
 * //           },
 * //           traceStatus: "ENABLED" || "DISABLED",
 * //           customPrompt: "STRING_VALUE",
 * //         },
 * //       },
 * //       sampleUtteranceGeneration: { // SampleUtteranceGenerationSpecification
 * //         enabled: true || false, // required
 * //         bedrockModelSpecification: {
 * //           modelArn: "STRING_VALUE", // required
 * //           guardrail: {
 * //             identifier: "STRING_VALUE", // required
 * //             version: "STRING_VALUE", // required
 * //           },
 * //           traceStatus: "ENABLED" || "DISABLED",
 * //           customPrompt: "STRING_VALUE",
 * //         },
 * //       },
 * //     },
 * //   },
 * // };
 *
 * ```
 *
 * @param UpdateBotLocaleCommandInput - {@link UpdateBotLocaleCommandInput}
 * @returns {@link UpdateBotLocaleCommandOutput}
 * @see {@link UpdateBotLocaleCommandInput} for command's `input` shape.
 * @see {@link UpdateBotLocaleCommandOutput} for command's `response` shape.
 * @see {@link LexModelsV2ClientResolvedConfig | config} for LexModelsV2Client's `config` shape.
 *
 * @throws {@link ConflictException} (client fault)
 *  <p>The action that you tried to perform couldn't be completed because
 *          the resource is in a conflicting state. For example, deleting a bot
 *          that is in the CREATING state. Try your request again. </p>
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>The service encountered an unexpected condition. Try your request
 *          again.</p>
 *
 * @throws {@link PreconditionFailedException} (client fault)
 *  <p>Your request couldn't be completed because one or more request
 *          fields aren't valid. Check the fields in your request and try
 *          again.</p>
 *
 * @throws {@link ServiceQuotaExceededException} (client fault)
 *  <p>You have reached a quota for your bot. </p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>Your request rate is too high. Reduce the frequency of
 *          requests.</p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>One of the input parameters in your request isn't valid. Check the
 *          parameters and try your request again.</p>
 *
 * @throws {@link LexModelsV2ServiceException}
 * <p>Base exception class for all service exceptions from LexModelsV2 service.</p>
 *
 * @public
 */
export declare class UpdateBotLocaleCommand extends UpdateBotLocaleCommand_base {
}
